@@ -1,4 +1,4 @@
-// $Id: fmtx-32.c,v 1.1 2004/06/16 10:06:03 ensc Exp $    --*- c -*--
+// $Id: fmtx-32.c 1890 2005-03-17 14:46:19Z ensc $    --*- c -*--
 
 // Copyright (C) 2003 Enrico Scholz <enrico.scholz@informatik.tu-chemnitz.de>
 //  
@@ -28,5 +28,5 @@ size_t	FMT_P(xulong)(char *ptr, unsigned long val) ALIASFUNC(xuint32);
 size_t	FMT_P( xlong)(char *ptr,          long val) ALIASFUNC( xint32);
 #endif
 
-size_t	FMT_P(xuint) (char *ptr, unsigned int val, char base) ALIASFUNC(xuint32);
-size_t	FMT_P( xint) (char *ptr,          int val, char base) ALIASFUNC( xint32);
+size_t	FMT_P(xuint) (char *ptr, unsigned int val)  ALIASFUNC(xuint32);
+size_t	FMT_P( xint) (char *ptr,          int val)  ALIASFUNC( xint32);
