@@ -1,4 +1,4 @@
-// $Id: string.h,v 1.2 2004/10/19 21:05:43 ensc Exp $    --*- c -*--
+// $Id: string.h 1914 2005-03-18 00:20:30Z ensc $    --*- c -*--
 
 // Copyright (C) 2004 Enrico Scholz <enrico.scholz@informatik.tu-chemnitz.de>
 //  
@@ -28,7 +28,7 @@ typedef struct
 } String;
 
 static void	String_init(String *);
-void		String_destroy(String *);
+static void	String_free(String *);
 
 #define ENSC_STRING_FIXED(VAL) { .d = VAL, .l = (sizeof(VAL)-1) }
 #define ENSC_STRING_ASSIGN_FIXED(DST,VAL) \
