@@ -1,4 +1,4 @@
-// $Id: fstool.c 2473 2007-01-25 09:51:43Z dhozac $    --*- c -*--
+// $Id: fstool.c 2732 2008-07-11 15:20:35Z dhozac $    --*- c -*--
 
 // Copyright (C) 2004 Enrico Scholz <enrico.scholz@informatik.tu-chemnitz.de>
 //  
@@ -203,6 +203,7 @@ int main(int argc, char *argv[])
       case CMD_WATCH		:  args.set_mask |= VC_IATTR_WATCH;	break;
       case CMD_HIDE		:  args.set_mask |= VC_IATTR_HIDE;	break;
       case CMD_BARRIER		:  args.set_mask |= VC_IATTR_BARRIER;	break;
+      case CMD_WRITE		:  args.set_mask |= VC_IATTR_WRITE;	break;
       case CMD_UNSET_IMMU	:  args.del_mask |= VC_IATTR_IMMUTABLE; /*@fallthrough@*/
       case CMD_UNSET_IMMUX	:  args.del_mask |= VC_IATTR_IUNLINK;	break;
       case CMD_UNSET_IMMUTABLE	:  args.del_mask |= VC_IATTR_IMMUTABLE;	break;
@@ -210,6 +211,7 @@ int main(int argc, char *argv[])
       case CMD_UNSET_WATCH	:  args.del_mask |= VC_IATTR_WATCH;	break;
       case CMD_UNSET_HIDE	:  args.del_mask |= VC_IATTR_HIDE;	break;
       case CMD_UNSET_BARRIER	:  args.del_mask |= VC_IATTR_BARRIER;	break;
+      case CMD_UNSET_WRITE	:  args.del_mask |= VC_IATTR_WRITE;	break;
       case 'R'			:  args.do_recurse     = true;		break;
       case 'a'			:  args.do_display_dot = true;		break;
       case 'd'			:  args.do_display_dir = true;		break;
