@@ -1,4 +1,4 @@
-// $Id: fstool.h 2473 2007-01-25 09:51:43Z dhozac $    --*- c -*--
+// $Id: fstool.h 2732 2008-07-11 15:20:35Z dhozac $    --*- c -*--
 
 // Copyright (C) 2004 Enrico Scholz <enrico.scholz@informatik.tu-chemnitz.de>
 //  
@@ -33,6 +33,7 @@
 #define CMD_HIDE		0x8013
 #define CMD_BARRIER		0x8014
 #define CMD_IMMUX		0x8015
+#define CMD_WRITE		0x8016
 #define CMD_UNSET_IMMU		0x8020
 #define CMD_UNSET_ADMIN		0x8021
 #define CMD_UNSET_WATCH		0x8022
@@ -40,6 +41,7 @@
 #define CMD_UNSET_BARRIER	0x8024
 #define CMD_UNSET_IMMUX		0x8025
 #define CMD_UNSET_IMMUTABLE	0x8026
+#define CMD_UNSET_WRITE		0x8027
 
 
 struct stat;
